==> owncloud-4.0.4.tgz: owncloud/apps/calendar/l10n/ko.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "달력이 없습니다",
"No events found." => "일정이 없습니다",
"Wrong calendar" => "잘못된 달력",
"New Timezone:" => "새로운 시간대 설정",
"Timezone changed" => "시간대 변경됨",
"Invalid request" => "잘못된 요청",
"Calendar" => "달력",
"Birthday" => "생일",
"Business" => "사업",
"Call" => "통화",
"Clients" => "클라이언트",
"Deliverer" => "배송",
"Holidays" => "공휴일",
"Ideas" => "생각",
"Journey" => "여행",
"Jubilee" => "기념일",
"Meeting" => "미팅",
"Other" => "기타",
"Personal" => "개인",
"Projects" => "프로젝트",
"Questions" => "질문",
"Work" => "작업",
"unnamed" => "익명의",
"Does not repeat" => "반복 없음",
"Daily" => "매일",
"Weekly" => "매주",
"Every Weekday" => "매주 특정 요일",
"Bi-Weekly" => "2주마다",
"Monthly" => "매월",
"Yearly" => "매년",
"never" => "전혀",
"by occurrences" => "번 이후",
"by date" => "날짜",
"by monthday" => "월",
"by weekday" => "주",
"Monday" => "월요일",
"Tuesday" => "화요일",
"Wednesday" => "수요일",
"Thursday" => "목요일",
"Friday" => "금요일",
"Saturday" => "토요일",
"Sunday" => "일요일",
"events week of month" => "이달의 한 주 일정",
"first" => "첫번째",
"second" => "두번째",
"third" => "세번째",
"fourth" => "네번째",
"fifth" => "다섯번째",
"last" => "마지막",
"January" => "1월",
"February" => "2월",
"March" => "3월",
"April" => "4월",
"May" => "5월",
"June" => "6월",
"July" => "7월",
"August" => "8월",
"September" => "9월",
"October" => "10월",
"November" => "11월",
"December" => "12월",
"by events date" => "이벤트 날짜 순",
"by yearday(s)" => "날짜 번호 순",
"by weeknumber(s)" => "주 번호 순",
"by day and month" => "날짜 순",
"Date" => "날짜",
"Cal." => "달력",
"All day" => "매일",
"New Calendar" => "새로운 달력",
"Missing fields" => "기입란이 비어있습니다",
"Title" => "제목",
"From Date" => "시작날짜",
"From Time" => "시작시간",
"To Date" => "마침 날짜",
"To Time" => "마침 시간",
"The event ends before it starts" => "마침일정이 시작일정 보다 빠릅니다. ",
"There was a database fail" => "데이터베이스 에러입니다.",
"Week" => "주",
"Month" => "달",
"List" => "목록",
"Today" => "오늘",
"Calendars" => "달력",
"There was a fail, while parsing the file." => "파일을 처리하는 중 오류가 발생하였습니다.",
"Choose active calendars" => "활성 달력 선택",
"Your calendars" => "내 달력",
"CalDav Link" => "CalDav 링크",
"Shared calendars" => "공유 달력",
"No shared calendars" => "달력 공유하지 않음",
"Share Calendar" => "달력 공유",
"Download" => "다운로드",
"Edit" => "편집",
"Delete" => "삭제",
"shared with you by" => "로 인해 당신과 함께 공유",
"New calendar" => "새로운 달력",
"Edit calendar" => "달력 편집",
"Displayname" => "표시 이름",
"Active" => "활성",
"Calendar color" => "달력 색상",
"Save" => "저장",
"Submit" => "보내기",
"Cancel" => "취소",
"Edit an event" => "이벤트 편집",
"Export" => "출력",
"Eventinfo" => "일정 정보",
"Repeating" => "반복",
"Alarm" => "알람",
"Attendees" => "참석자",
"Share" => "공유",
"Title of the Event" => "이벤트 제목",
"Category" => "분류",
"Separate categories with commas" => "쉼표로 카테고리 구분",
"Edit categories" => "카테고리 수정",
"All Day Event" => "종일 이벤트",
"From" => "시작",
"To" => "끝",
"Advanced options" => "고급 설정",
"Location" => "위치",
"Location of the Event" => "이벤트 위치",
"Description" => "설명",
"Description of the Event" => "이벤트 설명",
"Repeat" => "반복",
"Advanced" => "고급",
"Select weekdays" => "요일 선택",
"Select days" => "날짜 선택",
"and the events day of year." => "그리고 이 해의 일정",
"and the events day of month." => "그리고 이 달의 일정",
"Select months" => "달 선택",
"Select weeks" => "주 선택",
"and the events week of year." => "그리고 이 해의 주간 일정",
"Interval" => "간격",
"End" => "끝",
"occurrences" => "번 이후",
"Import a calendar file" => "달력 파일 가져오기",
"Please choose the calendar" => "달력을 선택해 주세요",
"create a new calendar" => "새 달력 만들기",
"Name of new calendar" => "새 달력 이름",
"Import" => "입력",
"Importing calendar" => "달력 입력",
"Calendar imported successfully" => "달력 입력을 성공적으로 마쳤습니다.",
"Close Dialog" => "대화 마침",
"Create a new event" => "새 이벤트 만들기",
"View an event" => "일정 보기",
"No categories selected" => "선택된 카테고리 없음",
"Select category" => "선택 카테고리",
"of" => "의",
"at" => "에서",
"Timezone" => "시간대",
"Check always for changes of the timezone" => "항상 시간대 변경 확인하기",
"Timeformat" => "시간 형식 설정",
"24h" => "24시간",
"12h" => "12시간",
"First day of the week" => "그 주의 첫째날",
"Calendar CalDAV syncing address:" => "달력 CalDav 동기화 주소",
"Users" => "사용자",
"select users" => "사용자 선택",
"Editable" => "편집 가능",
"Groups" => "그룹",
"select groups" => "선택 그룹",
"make public" => "공개"
);

==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/ko.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "모든 달력이 완벽히 캐시되지 않았습니다.",
"Everything seems to be completely cached" => "모든것이 완벽히 캐시 되었습니다.",
"No calendars found." => "달력이 없습니다",
"No events found." => "일정이 없습니다",
"Wrong calendar" => "잘못된 달력",
"The file contained either no events or all events are already saved in your calendar." => "이 파일은 이벤트가 없거나 모든 이벤트들이 이미 당신의 달력에 저장되어있습니다. ",
"events has been saved in the new calendar" => "이벤트가 새로운 달력에 저장되었습니다.",
"Import failed" => "가져오기 실패",
"events has been saved in your calendar" => "이벤트가 당신의 달력에 저장되었습니다.",
"New Timezone:" => "새로운 시간대 설정",
"Timezone changed" => "시간대 변경됨",
"Invalid request" => "잘못된 요청",
"Calendar" => "달력",
"Editable" => "편집 가능",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Birthday" => "생일",
"Business" => "사업",
"Call" => "통화",
"Clients" => "클라이언트",
"Deliverer" => "배송",
"Holidays" => "공휴일",
"Ideas" => "생각",
"Journey" => "여행",
"Jubilee" => "기념일",
"Meeting" => "미팅",
"Other" => "기타",
"Personal" => "개인",
"Projects" => "프로젝트",
"Questions" => "질문",
"Work" => "작업",
"by" => "로",
"unnamed" => "익명의",
"New Calendar" => "새로운 달력",
"Does not repeat" => "반복 없음",
"Daily" => "매일",
"Weekly" => "매주",
"Every Weekday" => "매주 특정 요일",
"Bi-Weekly" => "2주마다",
"Monthly" => "매월",
"Yearly" => "매년",
"never" => "전혀",
"by occurrences" => "번 이후",
"by date" => "날짜",
"by monthday" => "월",
"by weekday" => "주",
"Monday" => "월요일",
"Tuesday" => "화요일",
"Wednesday" => "수요일",
"Thursday" => "목요일",
"Friday" => "금요일",
"Saturday" => "토요일",
"Sunday" => "일요일",
"events week of month" => "이달의 한 주 일정",
"first" => "첫번째",
"second" => "두번째",
"third" => "세번째",
"fourth" => "네번째",
"fifth" => "다섯번째",
"last" => "마지막",
"January" => "1월",
"February" => "2월",
"March" => "3월",
"April" => "4월",
"May" => "5월",
"June" => "6월",
"July" => "7월",
"August" => "8월",
"September" => "9월",
"October" => "10월",
"November" => "11월",
"December" => "12월",
"by events date" => "이벤트 날짜 순",
"by yearday(s)" => "날짜 번호 순",
"by weeknumber(s)" => "주 번호 순",
"by day and month" => "날짜 순",
"Date" => "날짜",
"Cal." => "달력",
"Sun." => "일요일",
"Mon." => "월요일",
"Tue." => "화요일",
"Wed." => "수요일",
"Thu." => "목요일",
"Fri." => "금요일",
"Sat." => "토요일",
"Jan." => "1월",
"Feb." => "2월",
"Mar." => "3월",
"Apr." => "4월",
"May." => "5월",
"Jun." => "6월",
"Jul." => "7월",
"Aug." => "8월",
"Sep." => "9월",
"Oct." => "10월",
"Nov." => "11월",
"Dec." => "12월",
"All day" => "매일",
"Missing fields" => "기입란이 비어있습니다",
"Title" => "제목",
"From Date" => "시작날짜",
"From Time" => "시작시간",
"To Date" => "마침 날짜",
"To Time" => "마침 시간",
"The event ends before it starts" => "마침일정이 시작일정 보다 빠릅니다. ",
"There was a database fail" => "데이터베이스 에러입니다.",
"Week" => "주",
"Month" => "달",
"List" => "목록",
"Today" => "오늘",
"Settings" => "세팅",
"Your calendars" => "내 달력",
"CalDav Link" => "CalDav 링크",
"Share Calendar" => "달력 공유",
"Download" => "다운로드",
"Edit" => "편집",
"Delete" => "삭제",
"shared with you by" => "로 인해 당신과 함께 공유",
"New calendar" => "새로운 달력",
"Edit calendar" => "달력 편집",
"Displayname" => "표시 이름",
"Active" => "활성",
"Calendar color" => "달력 색상",
"Save" => "저장",
"Submit" => "보내기",
"Cancel" => "취소",
"Edit an event" => "이벤트 편집",
"Export" => "출력",
"Eventinfo" => "일정 정보",
"Repeating" => "반복",
"Alarm" => "알람",
"Attendees" => "참석자",
"Share" => "공유",
"Title of the Event" => "이벤트 제목",
"Category" => "분류",
"Separate categories with commas" => "쉼표로 카테고리 구분",
"Edit categories" => "카테고리 수정",
"All Day Event" => "종일 이벤트",
"From" => "시작",
"To" => "끝",
"Advanced options" => "고급 설정",
"Location" => "위치",
"Location of the Event" => "이벤트 위치",
"Description" => "설명",
"Description of the Event" => "이벤트 설명",
"Repeat" => "반복",
"Advanced" => "고급",
"Select weekdays" => "요일 선택",
"Select days" => "날짜 선택",
"and the events day of year." => "그리고 이 해의 일정",
"and the events day of month." => "그리고 이 달의 일정",
"Select months" => "달 선택",
"Select weeks" => "주 선택",
"and the events week of year." => "그리고 이 해의 주간 일정",
"Interval" => "간격",
"End" => "끝",
"occurrences" => "번 이후",
"create a new calendar" => "새 달력 만들기",
"Import a calendar file" => "달력 파일 가져오기",
"Please choose a calendar" => "달력을 선택하세요",
"Name of new calendar" => "새 달력 이름",
"Take an available name!" => "사용 가능한 이름을 쓰세요!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "이 이름의 달력은 이미 존재합니다. 계속 하신다면 이 달력들은 통합됩니다. ",
"Import" => "입력",
"Close Dialog" => "대화 마침",
"Create a new event" => "새 이벤트 만들기",
"View an event" => "일정 보기",
"No categories selected" => "선택된 카테고리 없음",
"of" => "의",
"at" => "에서",
"General" => "일반",
"Timezone" => "시간대",
"Update timezone automatically" => "자동으로 시간대를 업데이트",
"Time format" => "시간 포멧",
"24h" => "24시간",
"12h" => "12시간",
"Start week on" => "에 주 시작",
"Cache" => "캐시",
"Clear cache for repeating events" => "이벤트 반복을 위한 캐시 삭제",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "CalDAV 달력 주소 동기화",
"more info" => "더 많은 정보",
"Primary address (Kontact et al)" => "기본 주소 (Kontact 외)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "iCalendar 링크만 읽기"
);
